@@ -1,11 +1,12 @@
-import os 
+import os
 import numpy as np
 import seaborn as sbrn
 import matplotlib.pyplot as plt
 from bionetgen.core import BNGResult
 
+
 class BNGPlotter:
-    '''
+    """
     Class that does basic plotting for gdat/cdat files
 
     Usage BNGPlotter(inp, out, kwargs)
@@ -17,15 +18,16 @@ class BNGPlotter:
     out : str
         output file path
     kwargs : dict
-        keywords arguments for matplotlib. For details check 
+        keywords arguments for matplotlib. For details check
         bionetgen plot -h
 
     Methods
     -------
-    plot() 
-        plots the data from the input file and saves it to 
+    plot()
+        plots the data from the input file and saves it to
         output file the class is initialized with
-    '''
+    """
+
     def __init__(self, inp, out, **kwargs):
         # read input and output paths
         self.inp = inp
@@ -37,12 +39,17 @@ class BNGPlotter:
 
     def plot(self):
         # let's determine the type of plot we are doing
-        if self.result.file_extension == ".gdat" or self.result.file_extension == ".cdat": 
+        if (
+            self.result.file_extension == ".gdat"
+            or self.result.file_extension == ".cdat"
+        ):
             self._datplot()
         elif self.result.file_extension == ".scan":
             self._datplot()
         else:
-            print("File type not recognized, only gdat/cdat and scan files are implemented")
+            print(
+                "File type not recognized, only gdat/cdat and scan files are implemented"
+            )
             raise NotImplementedError
 
     def _datplot(self):
@@ -55,30 +62,32 @@ class BNGPlotter:
         ctr = 0
         ax = None
         for name in names:
-            if name == x_name: 
+            if name == x_name:
                 continue
             ax = sbrn.lineplot(x=self.data[x_name], y=self.data[name], label=name)
             ctr += 1
 
-        assert ax is not None, "No data columns are found in file {}".format(self.result.direct_path)
-    
+        assert ax is not None, "No data columns are found in file {}".format(
+            self.result.direct_path
+        )
+
         fax = ax.get_figure().gca()
         if not self.kwargs.get("legend", False):
             fax.legend().remove()
-        oxmin,oxmax = fax.get_xlim()
-        oymin,oymax = fax.get_ylim()
+        oxmin, oxmax = fax.get_xlim()
+        oymin, oymax = fax.get_ylim()
 
         xmin = self.kwargs.get("xmin", False) or oxmin
         xmax = self.kwargs.get("xmax", False) or oxmax
         ymin = self.kwargs.get("ymin", False) or oymin
         ymax = self.kwargs.get("ymax", False) or oymax
 
-        fax.set_xlim(xmin,xmax)
-        fax.set_ylim(ymin,ymax)
+        fax.set_xlim(xmin, xmax)
+        fax.set_ylim(ymin, ymax)
         # labels and title
         _ = plt.xlabel(self.kwargs.get("xlabel") or x_name)
         _ = plt.ylabel(self.kwargs.get("ylabel") or "concentration")
         _ = plt.title(self.kwargs.get("title") or self.result.file_name)
 
         # save the figure
-        plt.savefig(self.out)
\ No newline at end of file
+        plt.savefig(self.out)
