@@ -11,12 +11,13 @@ from .xmlparsers import RuleBlockXML
 # This allows access to the CLIs config setup
 app = BioNetGen()
 app.setup()
-conf = app.config['bionetgen']
-def_bng_path = conf['bngpath']
+conf = app.config["bionetgen"]
+def_bng_path = conf["bngpath"]
+
 
 class BNGParser:
-    '''
-    Parser object that deals with reading in the BNGL file and 
+    """
+    Parser object that deals with reading in the BNGL file and
     setting up the model object
 
     Usage: BNGParser(bngl_path)
@@ -26,28 +27,29 @@ class BNGParser:
     ----------
     bngfile : BNGFile
         BNGFile object that's responsible for .bngl file manipulations
-    
+
     Methods
     -------
     parse_model(model_file)
         parses the BNGL model at the given path and adds everything to a given model object
     parse_xml(xml_str)
         parses given xml string and adds everything to a given model object
-    '''
+    """
+
     def __init__(self, path, BNGPATH=def_bng_path) -> None:
         self.bngfile = BNGFile(path)
-    
+
     def parse_model(self, model_obj) -> None:
-        '''
+        """
         Will determine the parser route eventually and call the right
-        parser 
-        '''
+        parser
+        """
         self._parse_model_bngpl(model_obj)
 
     def _parse_model_bngpl(self, model_obj) -> None:
         # get file path
         model_file = self.bngfile.path
-        
+
         # this route runs BNG2.pl on the bngl and parses
         # the XML instead
         if model_file.endswith(".bngl"):
@@ -71,25 +73,25 @@ class BNGParser:
     def parse_xml(self, xml_str, model_obj) -> None:
         xml_dict = xmltodict.parse(xml_str)
         model_obj.xml_dict = xml_dict
-        xml_model = xml_dict['sbml']['model']
-        model_obj.model_name = xml_model['@id']
+        xml_model = xml_dict["sbml"]["model"]
+        model_obj.model_name = xml_model["@id"]
         for listkey in xml_model.keys():
             if listkey == "ListOfParameters":
                 param_list = xml_model[listkey]
                 if param_list is not None:
-                    params = param_list['Parameter']
+                    params = param_list["Parameter"]
                     xml_parser = ParameterBlockXML(params)
                     model_obj.add_block(xml_parser.parsed_obj)
             elif listkey == "ListOfObservables":
                 obs_list = xml_model[listkey]
                 if obs_list is not None:
-                    obs = obs_list['Observable']
+                    obs = obs_list["Observable"]
                     xml_parser = ObservableBlockXML(obs)
                     model_obj.add_block(xml_parser.parsed_obj)
             elif listkey == "ListOfCompartments":
                 comp_list = xml_model[listkey]
                 if comp_list is not None:
-                    comps = comp_list['compartment']
+                    comps = comp_list["compartment"]
                     xml_parser = CompartmentBlockXML(comps)
                     model_obj.add_block(xml_parser.parsed_obj)
             elif listkey == "ListOfMoleculeTypes":
@@ -115,8 +117,8 @@ class BNGParser:
                 # TODO: Add arguments correctly
                 func_list = xml_model[listkey]
                 if func_list is not None:
-                    funcs = func_list['Function']
+                    funcs = func_list["Function"]
                     xml_parser = FunctionBlockXML(funcs)
                     model_obj.add_block(xml_parser.parsed_obj)
         # And that's the end of parsing
-        print("Parsing complete")
\ No newline at end of file
+        print("Parsing complete")
