@@ -6,10 +6,11 @@ from bionetgen.core.main import BNGCLI
 # This allows access to the CLIs config setup
 app = BioNetGen()
 app.setup()
-conf = app.config['bionetgen']
+conf = app.config["bionetgen"]
+
 
 def run(inp, out=None):
-    '''
+    """
     Convenience function to run BNG2.pl as a library
 
     Usage: run(path_to_input_file, output_folder)
@@ -18,10 +19,10 @@ def run(inp, out=None):
     ---------
     path_to_input_file : str
         this has to point to a BNGL file
-    output_folder : str 
+    output_folder : str
         (optional) this points to a folder to put the results
         into. If it doesn't exist, it will be created.
-    '''
+    """
     # if out is None we make a temp directory
     if out is None:
         cur_dir = os.getcwd()
